Author: ion
Date: Sat Feb 4 20:45:02 2017
New Revision: 73685
URL:
http://svn.reactos.org/svn/reactos?rev=73685&view=rev
Log:
[BOOTLIB]: Super cool that y'all went and fixed typos in the codebase, but fixing UEFI
Official Specification Headers in our source tree is a bit much. Please submit a pull
request to EDK-II if you'd like.
Modified:
trunk/reactos/boot/environ/include/efi/BlockIo.h
trunk/reactos/boot/environ/include/efi/ProcessorBind.h
trunk/reactos/boot/environ/include/efi/SimpleTextOut.h
trunk/reactos/boot/environ/include/efi/UefiSpec.h
trunk/reactos/boot/environ/include/efi/UgaDraw.h
Modified: trunk/reactos/boot/environ/include/efi/BlockIo.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/B…
==============================================================================
--- trunk/reactos/boot/environ/include/efi/BlockIo.h [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/BlockIo.h [iso-8859-1] Sat Feb 4 20:45:02
2017
@@ -96,7 +96,7 @@
@retval EFI_WRITE_PROTECTED The device can not be written to.
@retval EFI_DEVICE_ERROR The device reported an error while performing the write.
@retval EFI_NO_MEDIA There is no media in the device.
- @retval EFI_MEDIA_CHANGED The MediaId does not match the current device.
+ @retval EFI_MEDIA_CHNAGED The MediaId does not matched the current device.
@retval EFI_BAD_BUFFER_SIZE The Buffer was not a multiple of the block size of the
device.
@retval EFI_INVALID_PARAMETER The write request contains LBAs that are not valid,
or the buffer is not on proper alignment.
@@ -118,7 +118,7 @@
@param This Indicates a pointer to the calling context.
@retval EFI_SUCCESS All outstanding data was written to the device
- @retval EFI_DEVICE_ERROR The device reported an error while writing back the data
+ @retval EFI_DEVICE_ERROR The device reported an error while writting back the data
@retval EFI_NO_MEDIA There is no media in the device.
**/
@@ -133,7 +133,7 @@
**/
typedef struct {
///
- /// The current media Id. If the media changes, this value is changed.
+ /// The curent media Id. If the media changes, this value is changed.
///
UINT32 MediaId;
@@ -144,7 +144,7 @@
///
/// TRUE if there is a media currently present in the device;
- /// otherwise, FALSE. THis field shows the media present status
+ /// othersise, FALSE. THis field shows the media present status
/// as of the most recent ReadBlocks() or WriteBlocks() call.
///
BOOLEAN MediaPresent;
Modified: trunk/reactos/boot/environ/include/efi/ProcessorBind.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/P…
==============================================================================
--- trunk/reactos/boot/environ/include/efi/ProcessorBind.h [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/ProcessorBind.h [iso-8859-1] Sat Feb 4
20:45:02 2017
@@ -79,7 +79,7 @@
#pragma warning ( disable : 4057 )
//
-// ASSERT(FALSE) or while (TRUE) are legal constructs so suppress this warning
+// ASSERT(FALSE) or while (TRUE) are legal constructes so supress this warning
//
#pragma warning ( disable : 4127 )
Modified: trunk/reactos/boot/environ/include/efi/SimpleTextOut.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/S…
==============================================================================
--- trunk/reactos/boot/environ/include/efi/SimpleTextOut.h [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/SimpleTextOut.h [iso-8859-1] Sat Feb 4
20:45:02 2017
@@ -146,10 +146,10 @@
#define EFI_WIDE_ATTRIBUTE 0x80
/**
-Reset the text output device hardware and optionally run diagnostics
+Reset the text output device hardware and optionaly run diagnostics
@param This The protocol instance pointer.
-@param ExtendedVerification Driver may perform more exhaustive verification
+@param ExtendedVerification Driver may perform more exhaustive verfication
operation of the device during reset.
@retval EFI_SUCCESS The text output device was reset.
@@ -368,7 +368,7 @@
///
INT32 CursorRow;
///
- /// The cursor is currently visible or not.
+ /// The cursor is currently visbile or not.
///
BOOLEAN CursorVisible;
} EFI_SIMPLE_TEXT_OUTPUT_MODE;
Modified: trunk/reactos/boot/environ/include/efi/UefiSpec.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/U…
==============================================================================
--- trunk/reactos/boot/environ/include/efi/UefiSpec.h [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/UefiSpec.h [iso-8859-1] Sat Feb 4 20:45:02
2017
@@ -817,7 +817,7 @@
@retval EFI_SUCCESS Image was loaded into memory correctly.
@retval EFI_NOT_FOUND Both SourceBuffer and DevicePath are NULL.
-@retval EFI_INVALID_PARAMETER One or more parameters are invalid.
+@retval EFI_INVALID_PARAMETER One or more parametes are invalid.
@retval EFI_UNSUPPORTED The image type is not supported.
@retval EFI_OUT_OF_RESOURCES Image was not loaded due to insufficient resources.
@retval EFI_LOAD_ERROR Image was not loaded because the image format was corrupt
or not
@@ -969,7 +969,7 @@
///
/// Used to induce a system-wide reset. This sets all circuitry within the
/// system to its initial state. This type of reset is asynchronous to system
- /// operation and operates without regard to cycle boundaries. EfiColdReset
+ /// operation and operates withgout regard to cycle boundaries. EfiColdReset
/// is tantamount to a system power cycle.
///
EfiResetCold,
@@ -1277,7 +1277,7 @@
@retval EFI_UNSUPPORTED Handle does not support Protocol.
@retval EFI_INVALID_PARAMETER One or more parameters are invalid.
@retval EFI_ACCESS_DENIED Required attributes can't be supported in current
environment.
-@retval EFI_ALREADY_STARTED Item on the open list already has required attributes whose
agent
+@retval EFI_ALREADY_STARTED Item on the open list already has requierd attributes whose
agent
handle is the same as AgentHandle.
**/
@@ -1637,13 +1637,13 @@
@param CapsuleHeaderArray Virtual pointer to an array of virtual pointers to the
capsules
being passed into update capsule.
@param CapsuleCount Number of pointers to EFI_CAPSULE_HEADER in
-CapsuleHeaderArray.
+CaspuleHeaderArray.
@param ScatterGatherList Physical pointer to a set of
EFI_CAPSULE_BLOCK_DESCRIPTOR that describes the
location in physical memory of a set of capsules.
@retval EFI_SUCCESS Valid capsule was passed. If
-CAPSULE_FLAGS_PERSIST_ACROSS_RESET is not set, the
+CAPSULE_FLAGS_PERSIT_ACROSS_RESET is not set, the
capsule has been successfully processed by the firmware.
@retval EFI_INVALID_PARAMETER CapsuleSize is NULL, or an incompatible set of flags were
set in the capsule header.
@@ -1667,8 +1667,8 @@
@param CapsuleHeaderArray Virtual pointer to an array of virtual pointers to the
capsules
being passed into update capsule.
@param CapsuleCount Number of pointers to EFI_CAPSULE_HEADER in
-CapsuleHeaderArray.
-@param MaximumCapsuleSize On output the maximum size that UpdateCapsule() can
+CaspuleHeaderArray.
+@param MaxiumCapsuleSize On output the maximum size that UpdateCapsule() can
support as an argument to UpdateCapsule() via
CapsuleHeaderArray and ScatterGatherList.
@param ResetType Returns the type of reset required for the capsule update.
Modified: trunk/reactos/boot/environ/include/efi/UgaDraw.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/U…
==============================================================================
--- trunk/reactos/boot/environ/include/efi/UgaDraw.h [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/UgaDraw.h [iso-8859-1] Sat Feb 4 20:45:02
2017
@@ -85,7 +85,7 @@
} EFI_UGA_PIXEL_UNION;
///
/// Enumeration value for actions of Blt operations.
///
typedef enum {
EfiUgaVideoFill, ///< Write data from the BltBuffer pixel (SourceX,
SourceY)
@@ -112,8 +112,8 @@
///< (DestinationX, DestinationY) (DestinationX + Width,
DestinationY + Height).
///< The BltBuffer and Delta are not used in this mode.
- EfiUgaBltMax ///< Maximum value for enumeration value of Blt operation.
If a Blt operation
- ///< larger or equal to this enumeration value, it is
invalid.
+ EfiUgaBltMax ///< Maxmimum value for enumration value of Blt operation.
If a Blt operation
+ ///< larger or equal to this enumration value, it is
invalid.
} EFI_UGA_BLT_OPERATION;
/**
@@ -133,7 +133,7 @@
@retval EFI_SUCCESS - The Blt operation completed.
@retval EFI_INVALID_PARAMETER - BltOperation is not valid.
- @retval EFI_DEVICE_ERROR - A hardware error occured writing to the video
buffer.
+ @retval EFI_DEVICE_ERROR - A hardware error occured writting to the video
buffer.
**/
typedef
@@ -85,7 +85,7 @@
} EFI_UGA_PIXEL_UNION;
///
-/// Enumeration value for actions of Blt operations.
+/// Enumration value for actions of Blt operations.
///
typedef enum {